import React from 'react';
import type { ReactNode } from 'react';
import type { ModalProps } from 'antd';
export declare type CreateModalProps<T, R = undefined> = Omit<ModalProps, 'onOk' | 'visible' | 'destroyOnClose' | 'confirmLoading'> & {
    /**
     * @description An alias to `children` prop. The modal body content, usually a form.
     * @description.zh-CN `children`的别名，弹窗内容，通常是一个表单。
     * */
    content?: ReactNode;
    /**
     * @description Same as content prop, but higher priority
     * @description.zh-CN 同 content ，优先级高于 content
     * */
    render?: (formRef: React.MutableRefObject<any | undefined>) => ReactNode;
    /**
     * @description "Ok" button events that return a Promise can delay closing. Parameter is the value passed by the content, the return value will be passed to the final return Promise.
     * @description.zh-CN “确认”按钮事件，返回 promise 可以延迟关闭。参数为弹窗内容传递的值，返回值会被传递给最终返回的 Promise。
     * */
    onOk?: (values?: T) => Promise<R> | R | undefined;
    /**
     * @description Callback for validation failure and onOk failure, will not cause the modal to close, and will not cause the final returned Promise to reject
     * @description.zh-CN 验证失败和 onOk 失败的回调，不会导致弹窗关闭，也不会导致最终返回的 Promise reject
     * */
    onFailed?: (error: unknown) => any;
};
export declare type CreateModalReturn<T, R> = {
    /**
     * @description Results only when the modal is closed.
     * @description.zh-CN 弹窗关闭时才有的结果
     */
    promise: Promise<R>;
    destory: () => void;
};
export declare function TmpComp<T, R>({ content, children, render, onOk, onCancel, onFailed, ...rest }: CreateModalProps<T, R>): JSX.Element;
